floor — Pyskool 1.1.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pyskool 1.1.1 documentation »

# floor

Defines the `Floor` class.

class `floor.` `Floor`(floor_id, left_x, right_x, y)

  A region of the skool regarded as a starting point from which to reach a destination (which will be on the same or another floor).

  Parameters: | floor_id – The floor’s unique ID. left_x – The x-coordinate of the left edge of the floor. right_x – The x-coordinate of the right edge of the floor. y – The y-coordinate of the floor.

  `below`(character)

    Return whether this floor is below a character’s current location.

    Parameters: | character (`Character`) – The character to check.

  `contains_location`(x, y)

    Return whether the location (x, y) is on this floor.

  `supports`(character)

    Return whether a character is on this floor.

    Parameters: | character (`Character`) – The character to check.

### Navigation

- index
- modules |
- next |
- previous |
- Pyskool 1.1.1 documentation »